@@ -1,23 +1,18 @@
-import asyncio
-import os
+import logging
 import threading
 
 import serial
 import serial.tools.list_ports
-from crownstone_core.protocol.BlePackets import ControlPacket
-from crownstone_core.protocol.BluenetTypes import ControlType
-from crownstone_uart.topics.UartTopics import UartTopics
 
 from crownstone_uart.core.UartEventBus import UartEventBus
-from crownstone_uart.core.dataFlowManagers.Collector import Collector
 from crownstone_uart.core.uart.UartParser import UartParser
 from crownstone_uart.core.uart.UartReadBuffer import UartReadBuffer
-from crownstone_uart.core.uart.UartTypes import UartTxType
-from crownstone_uart.core.uart.UartWrapper import UartWrapper
 from crownstone_uart.topics.SystemTopics import SystemTopics
 
+_LOGGER = logging.getLogger(__name__)
 
-class UartBridge (threading.Thread):
+
+class UartBridge(threading.Thread):
 
     def __init__(self, port, baudrate):
         self.baudrate = baudrate
@@ -25,70 +20,28 @@ class UartBridge (threading.Thread):
 
         self.serialController = None
         self.started = False
-        self.parser = None
-        self.eventId = 0
 
         self.running = True
-        
-        threading.Thread.__init__(self)
-
-
-    def __del__(self):
-        self.stop_sync()
-
-
-    async def handshake(self):
-        collector = Collector(timeout=0.25, topic=UartTopics.uartMessage)
-        self.echo("HelloCrownstone")
-        reply = await collector.receive()
-
-        if reply is not None:
-            if "string" in reply:
-                return reply["string"] == "HelloCrownstone"
-        return False
-
-
-    def echo(self, string):
-        controlPacket = ControlPacket(ControlType.UART_MESSAGE).loadString(string).getPacket()
-        uartPacket    = UartWrapper(UartTxType.CONTROL, controlPacket).getPacket()
-        self.write_to_uart(uartPacket)
-
-
-    async def starting(self):
-        counter = 0
-        while not self.started and counter < 2:
-            counter += 0.2
-            await asyncio.sleep(0.02)
-
-    def run(self):
         self.parser = UartParser()
         self.eventId = UartEventBus.subscribe(SystemTopics.uartWriteData, self.write_to_uart)
+        threading.Thread.__init__(self)
+
+    def __del__(self):
+        self.stop()
+
+    def run(self):
         self.start_serial()
         self.start_reading()
 
 
-    def stop_sync(self):
-        # print("Stopping UartBridge")
+    def stop(self):
         self.running = False
-        self.parser.stop()
         UartEventBus.unsubscribe(self.eventId)
-
-
-    async def stop(self):
-        self.stop_sync()
-        counter = 0
-        while self.serialController is not None and counter < 2:
-            counter += 0.1
-            await asyncio.sleep(0.1)
-
-
-    async def isAlive(self):
-        while self.serialController is not None and self.running:
-            await asyncio.sleep(0.1)
+        self.parser.stop()
 
 
     def start_serial(self):
-        # print("Initializing serial on port ", self.port, ' with baudrate ', self.baudrate)
+        _LOGGER.debug("UartBridge: Initializing serial on port {self.port} with baudrate {self.baudrate}")
         try:
             self.serialController = serial.Serial()
             self.serialController.port = self.port
@@ -96,13 +49,13 @@ class UartBridge (threading.Thread):
             self.serialController.timeout = 0.25
             self.serialController.open()
         except OSError or serial.SerialException or KeyboardInterrupt:
-            self.stop_sync()
+            self.stop()
 
 
     def start_reading(self):
         readBuffer = UartReadBuffer()
         self.started = True
-        # print("Read starting on serial port.")
+        _LOGGER.debug(F"Read starting on serial port.{self.port} {self.running}")
         try:
             while self.running:
                 bytesFromSerial = self.serialController.read()
@@ -115,17 +68,21 @@ class UartBridge (threading.Thread):
 
             # print("Cleaning up UartBridge")
         except OSError or serial.SerialException:
-            print("Connection Failed. Retrying...")
+            _LOGGER.info("Connection to USB Failed. Retrying...")
         except KeyboardInterrupt:
             self.running = False
-            print("Closing serial connection.")
+            _LOGGER.debug("Closing serial connection.")
 
-        self.started = False
+        # close the serial controller
         self.serialController.close()
         self.serialController = None
+        # remove the event listener pointing to the old connection
+        UartEventBus.unsubscribe(self.eventId)
+        self.started = False
+        UartEventBus.emit(SystemTopics.connectionClosed, True)
 
     def write_to_uart(self, data):
         if self.serialController is not None and self.started:
             self.serialController.write(data)
         else:
-            self.stop_sync()
+            self.stop()
